==> collective.categorizing-0.1.1.tar.gz: collective.categorizing-0.1.1/collective/categorizing/tests/test_integration.py <==
import unittest
import doctest

#from zope.testing import doctestunit
#from zope.component import testing, eventtesting

from Testing import ZopeTestCase as ztc

from collective.categorizing.tests import base

class CollectiveCategorizingIntegrationTestCase(base.CollectiveCategorizingTestCase):
    """Base class used for test cases
    """

    def afterSetUp( self ):
        """Code that is needed is the afterSetUp of both test cases.
        """
        self.setRoles(('Manager',))

def test_suite():
    return unittest.TestSuite([

        # Integration tests for adapters.
        ztc.ZopeDocFileSuite(
            'tests/integration/adapter_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

        # Integration tests for contents.
        ztc.ZopeDocFileSuite(
            'tests/integration/content_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

        # Integration tests for utilities.
        ztc.ZopeDocFileSuite(
            'tests/integration/utility_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

            ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')

==> collective.categorizing-0.2.2.tar.gz: collective.categorizing-0.2.2/collective/categorizing/tests/test_integration.py <==
import unittest
import doctest
from Testing import ZopeTestCase as ztc
from collective.categorizing.tests import base

class CollectiveCategorizingIntegrationTestCase(base.CollectiveCategorizingTestCase):
    """Base class used for test cases
    """

    def afterSetUp( self ):
        """Code that is needed is the afterSetUp of both test cases.
        """
        self.setRoles(('Manager',))

def test_suite():
    return unittest.TestSuite([

        # Integration tests for adapters.
        ztc.ZopeDocFileSuite(
            'tests/integration/adapter_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

        # Integration tests for contents.
        ztc.ZopeDocFileSuite(
            'tests/integration/content_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

        # Integration tests for utilities.
        ztc.ZopeDocFileSuite(
            'tests/integration/utility_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

        # Integration tests for utilities.
        ztc.ZopeDocFileSuite(
            'tests/integration/view_integration.txt', package='collective.categorizing',
            test_class=CollectiveCategorizingIntegrationTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),

            ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
